changeset 15499:399fbe0ffbc2

openat: Fix warnings and commens when building unlinkat.c on Hurd. * lib/unlinkat.c: Mention Hurd in comments. Include stdlib.h to get prototype for free.
author Simon Josefsson <simon@josefsson.org>
date Fri, 05 Aug 2011 13:27:17 +0200
parents 7ed7c0ea6e5f
children b3a795f03c75
files ChangeLog lib/unlinkat.c
diffstat 2 files changed, 11 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,9 @@
+2011-08-05  Simon Josefsson  <simon@josefsson.org>
+
+	openat: Fix warnings and commens when building unlinkat.c on Hurd.
+	* lib/unlinkat.c: Mention Hurd in comments.  Include stdlib.h to
+	get prototype for free.
+
 2011-08-04  Bruno Haible  <bruno@clisp.org>
 
 	Tests for module 'pathmax'.
--- a/lib/unlinkat.c
+++ b/lib/unlinkat.c
@@ -1,4 +1,4 @@
 /* Work around unlinkat bugs on Solaris 9.
 
    Copyright (C) 2009-2011 Free Software Foundation, Inc.
 
@@ -26,6 +26,8 @@
 #include <string.h>
 #include <sys/stat.h>
 
+#include <stdlib.h>
+
 #include "dosname.h"
 #include "openat.h"
 
@@ -34,7 +36,8 @@
 # undef unlinkat
 
 /* unlinkat without AT_REMOVEDIR does not honor trailing / on Solaris
-   9.  Solve it in a similar manner to unlink.  */
+   9.  Solve it in a similar manner to unlink.  Hurd has the same
+   issue. */
 
 int
 rpl_unlinkat (int fd, char const *name, int flag)
@@ -1,4 +1,4 @@
-/* Work around unlinkat bugs on Solaris 9.
+/* Work around unlinkat bugs on Solaris 9 and Hurd.
 
    Copyright (C) 2009-2011 Free Software Foundation, Inc.